@@ -2,6 +2,8 @@ from ..filehandler import FileHandler
 from csv import reader, writer
 from portalocker import Lock
 from pandas import DataFrame
+from gc import collect
+from copy import deepcopy
 
 
 class CSVReader(FileHandler):
@@ -37,36 +39,42 @@ class CSVReader(FileHandler):
         row_num = 0
         header = None
 
-        with Lock(filename=self.file_path, mode='r') as read_obj, Lock(filename=self.file_path, mode='w') as write_obj:
-            csv_reader = reader(read_obj, self.dialect, **self.kwargs)
-            csv_writer = writer(write_obj)
+        try:
+            with Lock(filename=self.file_path, mode='r') as read_obj, Lock(filename=self.file_path, mode='w')\
+                    as write_obj:
+                csv_reader = reader(read_obj, self.dialect, **self.kwargs)
+                csv_writer = writer(write_obj)
 
-            for line in csv_reader:
-                data.append(line)
+                for line in csv_reader:
+                    data.append(line)
 
-                if not header:
-                    header = converted_row
+                    if not header:
+                        header = converted_row
 
-                if handler and buffer <= len(data):
-                    df = self.__to_df(data)
-                    handler(self.file_path, df, row_num - len(df) + 1, row_num, **self.kwargs)
-                    data.clear()
-                    data.append(header)
+                    if handler and buffer <= len(data):
+                        df = self.__to_df(data)
+                        handler(deepcopy(self.file_path), deepcopy(df), deepcopy(row_num - len(df) + 1),
+                                deepcopy(row_num), **self.kwargs)
+                        data.clear()
+                        data.append(header)
 
-                row_num += 1
+                    row_num += 1
 
-            if self.truncate:
-                for i, row in enumerate(csv_reader):
-                    if i > 0:
-                        csv_writer.writerow(row)
+                if self.truncate:
+                    for i, row in enumerate(csv_reader):
+                        if i > 0:
+                            csv_writer.writerow(row)
 
-        df = self.__to_df(data)
+            df = self.__to_df(data)
 
-        if not df.empty and handler:
-            row_num -= 1
-            handler(self.file_path, df, row_num - len(df) + 1, row_num, **self.kwargs)
-        elif not handler:
-            return df
+            if not df.empty and handler:
+                row_num -= 1
+                handler(deepcopy(self.file_path), deepcopy(df), deepcopy(row_num - len(df) + 1), deepcopy(row_num),
+                        **self.kwargs)
+            elif not handler:
+                return df
+        finally:
+            collect()
 
     @staticmethod
     def __to_df(data):
