@@ -167,13 +167,13 @@ class SQLEngineClass(BaseSQLEngineClass, PickleMixIn):
             engine.connect()
         else:
             engine = None
+            connect_args = {'timeout': self.__conn_timeout, 'connect_timeout': self.__conn_timeout,
+                            'options': '-c statement_timeout=%s' % self.__query_timeout}
 
             try:
                 engine = create_engine2(
-                    self.__sql_config.gen_conn_str(), connect_args={
-                        'timeout': self.__conn_timeout, 'connect_timeout': self.__conn_timeout,
-                        'options': '-c statement_timeout=%s' % self.__query_timeout}
-                )
+                    self.__sql_config.gen_conn_str(), connect_args=connect_args,
+                    autocommit=self.__sql_config.autocommit)
                 engine.commit()
             except Error as e:
                 close_engine(engine)
